pno integrates species probability (suitability) distributions (e.g. derived with MAXENT) with respect to single climatic (or other environmental) variables in order to get predicted niche occupancy (PNO) profiles for each species and environmenatal variable.pno(path_bioclim, path_model, subset = NULL,
bin_width = 1, bin_number = NULL)path_model is to be usedpath_bioclim and path_model point to the directories where the environmental data and the MAXENT probability distributions must be stored as ASCII maps with an ArcGIS-compatible header (as obtained with MAXENT output filetype: asc). An example header:
pno.weighted.mean,
niche.overlap,
anc.clim